@@ -1,6 +1,6 @@
 package Pod::PseudoPod::LaTeX;
 BEGIN {
-  $Pod::PseudoPod::LaTeX::VERSION = '1.101060';
+  $Pod::PseudoPod::LaTeX::VERSION = '1.101530';
 }
 
 use Pod::PseudoPod 0.16;
@@ -17,11 +17,12 @@ sub new
     my $self             = $class->SUPER::new(%args);
 
     $self->accept_targets_as_text(
-        qw( sidebar blockquote programlisting figure table PASM PIR PIR_FRAGMENT PASM_FRAGMENT PIR_FRAGMENT_INVALID)
+        qw( sidebar blockquote programlisting screen figure table PASM PIR PIR_FRAGMENT PASM_FRAGMENT PIR_FRAGMENT_INVALID)
     );
 
     $self->{scratch} ||= '';
     $self->{stack}     = [];
+    $self->{labels}     = { screen => 'Program output'};
 
     return $self;
 }
@@ -57,6 +58,8 @@ sub encode_text
     $text =~ s/\\/\\backslash/g;       # backslashes are special
     $text =~ s/([#\$&%_{}])/\\$1/g;
     $text =~ s/(\^)/\\char94{}/g;         # carets are special
+    $text =~ s/</\\textless{}/g;
+    $text =~ s/>/\\textgreater{}/g;
 
     $text =~ s/(\\backslash)/\$$1\$/g;    # add unescaped dollars
 
@@ -289,10 +292,17 @@ sub start_Verbatim
 {
     my $self = shift;
 
-    #	$self->{scratch} .= "\\addtolength{\\parskip}{-5pt}\n";
+    my $verb_options = "commandchars=\\\\\\{\\}";
+    eval {
+        if ($self->{curr_open}[-1][-1]{target} eq 'screen') {
+            $verb_options .= ',frame=single,label='
+                             . $self->{labels}{screen};
+        }
+    };
+
     $self->{scratch} .= "\\vspace{-6pt}\n"
                      .  "\\scriptsize\n"
-                     .  "\\begin{Verbatim}[commandchars=\\\\\\{\\}]\n";
+                     .  "\\begin{Verbatim}[$verb_options]\n";
     $self->{flags}{in_verbatim}++;
 }
 
@@ -308,6 +318,18 @@ sub end_Verbatim
     $self->emit();
 }
 
+
+sub end_screen
+{
+    my $self = shift;
+    $self->{scratch} .= "\n\\end{Verbatim}\n"
+                     .  "\\vspace{-6pt}\n";
+
+    #	$self->{scratch} .= "\\addtolength{\\parskip}{5pt}\n";
+    $self->{scratch} .= "\\normalsize\n";
+    $self->{flags}{in_verbatim}--;
+    $self->emit();
+}
 sub start_figure
 {
     my ( $self, $flags ) = @_;
@@ -565,7 +587,7 @@ Pod::PseudoPod::LaTeX - convert Pod::PseudoPod documents into LaTeX
 
 =head1 VERSION
 
-version 1.101060
+version 1.101530
 
 =head1 SYNOPSIS
 
